==> haskell-ordered-containers-0.2.4-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-FIPLivdtxh13rutp2945Ky
key:                  ordered-containers-0.2.4-FIPLivdtxh13rutp2945Ky
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  55603839b206665fad93758fa6de57e8
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-FIPLivdtxh13rutp2945Ky
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-LtdCyz5lRpSEDVfQGtCbHQ

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ordered-containers-0.2.4-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-25BZWJ1rdxFBYEsqKNbOR4
key:                  ordered-containers-0.2.4-25BZWJ1rdxFBYEsqKNbOR4
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  989c933bc2fbfea98df7184e6a0a5b16
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-25BZWJ1rdxFBYEsqKNbOR4
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-9MfualSpDNWnshBkTCGL2

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
